<?php

namespace Drupal\media_download_all\Plugin\Archiver;

use Drupal\Core\Archiver\Zip as BaseZip;
use Drupal\Core\Archiver\ArchiverException;

/**
 * Defines an archiver implementation for .zip files.
 *
 * @Archiver(
 *   id = "media_download_all_files_zip_archiver",
 *   title = @Translation("Media download all files zip archiver"),
 *   description = @Translation("Handles zip files for media download all files."),
 *   extensions = {"zip"}
 * )
 */
class Zip extends BaseZip {

  /**
   * {@inheritdoc}
   */
  public function __construct($file_path) {
    $this->zip = new \ZipArchive();
    if ($this->zip->open($file_path, \ZipArchive::CREATE) !== TRUE || (file_exists($file_path) && $this->zip->open($file_path, \ZipArchive::OVERWRITE) !== TRUE)) {
      throw new ArchiverException(t('Cannot open %file_path', ['%file_path' => $file_path]));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function add($file_path) {
    $local_name = \Drupal::service('file_system')->basename($file_path);
    $this->zip->addFile($file_path, $local_name);
    return $this;
  }

  /**
   * Method to close the opened archive file.
   */
  public function close() {
    $this->zip->close();
  }

}
